==> easymock_4.3.orig.tar.xz: easymock-easymock-4.3/core/src/test/java/org/easymock/tests/RecordStateInvalidReturnValueTest.java <==
/*
 * Copyright 2001-2021 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.easymock.tests;

import static org.easymock.EasyMock.*;
import static org.junit.Assert.*;

import org.junit.Before;
import org.junit.Test;

/**
 * @author OFFIS, Tammo Freese
 */
public class RecordStateInvalidReturnValueTest {

    private IMethods mock;

    @Before
    public void setup() {
        mock = createMock(IMethods.class);
    }

    @Test
    public void setInvalidBooleanReturnValue() {
        try {
            expect((Object) mock.oneArg(false)).andReturn(false);
            fail("IllegalStateException expected");
        } catch (IllegalStateException e) {
            assertEquals("incompatible return value type", e.getMessage());
        }

    }

    @Test
    public void setReturnValueForVoidMethod() {
        mock.simpleMethod();
        try {
            expectLastCall().andReturn(null);
            fail("IllegalStateException expected");
        } catch (IllegalStateException e) {
            assertEquals("void method cannot return a value", e.getMessage());
        }
    }

    @Test
    public void nullForPrimitive() {
        try {
            expect(mock.longReturningMethod(4)).andReturn(null);
            fail("null not allowed");
        } catch (IllegalStateException e) {
            assertEquals("can't return null for a method returning a primitive type", e.getMessage());
        }
    }
}

==> easymock_5.5.0.orig.tar.xz: easymock-easymock-5.5.0/core/src/test/java/org/easymock/tests/RecordStateInvalidReturnValueTest.java <==
/*
 * Copyright 2001-2024 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.easymock.tests;

import static org.easymock.EasyMock.*;

import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;

/**
 * @author OFFIS, Tammo Freese
 */
public class RecordStateInvalidReturnValueTest {

    private IMethods mock;

    @BeforeEach
    public void setup() {
        mock = createMock(IMethods.class);
    }

    @Test
    public void setInvalidBooleanReturnValue() {
        try {
            expect((Object) mock.oneArg(false)).andReturn(false);
            Assertions.fail("IllegalStateException expected");
        } catch (IllegalStateException e) {
            Assertions.assertEquals("incompatible return value type", e.getMessage());
        }

    }

    @Test
    public void setReturnValueForVoidMethod() {
        mock.simpleMethod();
        try {
            expectLastCall().andReturn(null);
            Assertions.fail("IllegalStateException expected");
        } catch (IllegalStateException e) {
            Assertions.assertEquals("void method cannot return a value", e.getMessage());
        }
    }

    @Test
    public void nullForPrimitive() {
        try {
            expect(mock.longReturningMethod(4)).andReturn(null);
            Assertions.fail("null not allowed");
        } catch (IllegalStateException e) {
            Assertions.assertEquals("can't return null for a method returning a primitive type", e.getMessage());
        }
    }
}
